summaryrefslogtreecommitdiff
path: root/include/llmr/util/raster.hpp
diff options
context:
space:
mode:
authorKonstantin Käfer <mail@kkaefer.com>2014-04-30 14:46:28 +0200
committerKonstantin Käfer <mail@kkaefer.com>2014-04-30 14:46:28 +0200
commit449f403e874388d752bce49c807abd51fa562fd2 (patch)
tree32d27345bb6c66fe103307ed86cecf36c52b7a9e /include/llmr/util/raster.hpp
parent52cd9a656173ab70de42b1115e3344614bfe08ef (diff)
downloadqtlocation-mapboxgl-449f403e874388d752bce49c807abd51fa562fd2.tar.gz
rename animation => transition
Diffstat (limited to 'include/llmr/util/raster.hpp')
-rw-r--r--include/llmr/util/raster.hpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/include/llmr/util/raster.hpp b/include/llmr/util/raster.hpp
index 58fb09faeb..0bca3a736e 100644
--- a/include/llmr/util/raster.hpp
+++ b/include/llmr/util/raster.hpp
@@ -1,7 +1,7 @@
#ifndef LLMR_UTIL_RASTER
#define LLMR_UTIL_RASTER
-#include <llmr/util/animation.hpp>
+#include <llmr/util/transition.hpp>
#include <llmr/util/texturepool.hpp>
#include <string>
@@ -29,10 +29,10 @@ public:
// loaded status
bool isLoaded() const;
- // animations
- void beginFadeInAnimation();
- bool needsAnimation() const;
- void updateAnimations(time now);
+ // transitions
+ void beginFadeInTransition();
+ bool needsTransition() const;
+ void updateTransitions(time now);
inline void setData(const std::string &img) { data = img; }
@@ -71,8 +71,8 @@ private:
// the raw pixels
char *img = nullptr;
- // fade in animation
- std::shared_ptr<util::animation> fade_animation = nullptr;
+ // fade in transition
+ std::shared_ptr<util::transition> fade_transition = nullptr;
};
}